import './style.css';
import * as THREE from 'three';
import { OrbitControls } from 'three/examples/jsm/controls/OrbitControls';

//scene setup
const scene = new THREE.Scene();
const camera = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight, 0.1, 1000);
const camera2 = new THREE.PerspectiveCamera(75, window.innerWidth / window.innerHeight, 0.1, 100);
const renderer = new THREE.WebGLRenderer({
  canvas: document.querySelector('#bg'),
});

renderer.setPixelRatio(window.devicePixelRatio);
renderer.setSize(window.innerWidth, window.innerHeight);
camera.position.setZ(30);
camera2.position.setZ(30);


//Monitors
const monitorGeo = new THREE.BoxGeometry(10,10,1);
const monitorMaterial = new THREE.MeshStandardMaterial({color: 0x0000ff});

const monitor1 = new THREE.Mesh(monitorGeo, monitorMaterial);

const monitor2 = new THREE.Mesh(monitorGeo, monitorMaterial);
monitor2.position.x = -15;
monitor2.position.z = 5;
monitor2.lookAt(camera2.position);

const monitor3 = new THREE.Mesh(monitorGeo, monitorMaterial);
monitor3.position.x = 15;
monitor3.position.z = 5;
monitor3.lookAt(camera2.position)

scene.add(monitor1, monitor2, monitor3);


// Lights

const pointLight = new THREE.PointLight(0xffffff);
pointLight.position.set(5, 5, 5);
scene.add(pointLight);

const ambientLight = new THREE.AmbientLight(0xffffff);
scene.add(ambientLight);

const lightHelper = new THREE.PointLightHelper(pointLight)
const gridHelper = new THREE.GridHelper(200, 50);
const camHelper = new THREE.CameraHelper(camera2);
scene.add(lightHelper, gridHelper, camHelper);

const controls = new OrbitControls(camera, renderer.domElement);

renderer.render(scene, camera);


function lookAtMonitor(monitor: number){
  switch (monitor) {
    case 1:
      camera2.lookAt(monitor1.position);
      break;
    case 2:
      camera2.lookAt(monitor2.position);
      break;
    case 3:
      camera2.lookAt(monitor3.position);
      break;
    default:
      break;
  }
  //camera.position.lerp(new THREE.Vector3(-10,0,30), 0.02)
  //camera.lookAt(new THREE.Vector3(-10, 0, 30));
}



function animate(){
  requestAnimationFrame(animate)

  controls.update();

  lookAtMonitor(3);

  renderer.render(scene, camera);

}

animate();